## simple_event_bus history

### 0.0.4

* fix error package

### 0.0.3

* independent event sources
* add remove method
* allow no param method to listening

### 0.0.2

* fix publish_event can not accept str event.

### 0.0.1

* Basic functions completed

### 0.0.0

* first commit
